Index: src/ia32/builtins-ia32.cc |
=================================================================== |
--- src/ia32/builtins-ia32.cc (revision 3935) |
+++ src/ia32/builtins-ia32.cc (working copy) |
@@ -63,10 +63,10 @@ |
ASSERT(extra_args == NO_EXTRA_ARGUMENTS); |
} |
// JumpToRuntime expects eax to contain the number of arguments |
// including the receiver and the extra arguments. |
__ add(Operand(eax), Immediate(num_extra_args + 1)); |
- __ JumpToRuntime(ExternalReference(id)); |
+ __ JumpToExternalReference(ExternalReference(id)); |
} |
@@ -63,10 +63,10 @@ |
ASSERT(extra_args == NO_EXTRA_ARGUMENTS); |
} |
- // JumpToRuntime expects eax to contain the number of arguments |
+ // JumpToExternalReference expects eax to contain the number of arguments |
// including the receiver and the extra arguments. |
__ add(Operand(eax), Immediate(num_extra_args + 1)); |